TTF_CopyOperation

Struct TTF_CopyOperation 

#[repr(C)]
pub struct TTF_CopyOperation { pub cmd: TTF_DrawCommand, pub text_offset: c_int, pub glyph_font: *mut TTF_Font, pub glyph_index: Uint32, pub src: SDL_Rect, pub dst: SDL_Rect, pub reserved: *mut c_void, }
A texture copy draw operation.

Availability

This struct is available since SDL_ttf 3.0.0.

See also

Fields

cmd: TTF_DrawCommandtext_offset: c_int

The offset in the text corresponding to this glyph. There may be multiple glyphs with the same text offset and the next text offset might be several Unicode codepoints later. In this case the glyphs and codepoints are grouped together and the group bounding box is the union of the dst rectangles for the corresponding glyphs.

glyph_font: *mut TTF_Font

The font containing the glyph to be drawn, can be passed to TTF_GetGlyphImageForIndex()

glyph_index: Uint32

The glyph index of the glyph to be drawn, can be passed to TTF_GetGlyphImageForIndex()

src: SDL_Rect

The area within the glyph to be drawn

dst: SDL_Rect

The drawing coordinates of the glyph, in pixels. The x coordinate is relative to the left side of the text area, going right, and the y coordinate is relative to the top side of the text area, going down.

reserved: *mut c_void