#[repr(C)]pub struct TTF_FillOperation {
pub cmd: TTF_DrawCommand,
pub rect: SDL_Rect,
}Expand description
Fields
cmd: TTF_DrawCommandrect: SDL_RectThe rectangle to fill, in pixels. The x coordinate is relative to the left side of the text area, going right, and the y coordinate is relative to the top side of the text area, going down.