TTF_GetTextScript

Function TTF_GetTextScript 

pub unsafe extern "C" fn TTF_GetTextScript(
    text: *mut TTF_Text,
) -> Uint32
Get the script used for text shaping a text object.

This defaults to the script of the font used by the text object.

Parameters

  • text: the text to query.

Return value

Returns an ISO 15924 code or 0 if a script hasn’t been set on either the text object or the font.

Thread safety

This function should be called on the thread that created the text.

Availability

This function is available since SDL_ttf 3.0.0.

See also