#[repr(C)]pub struct TTF_SubString {
pub flags: TTF_SubStringFlags,
pub offset: c_int,
pub length: c_int,
pub line_index: c_int,
pub cluster_index: c_int,
pub rect: SDL_Rect,
}Expand description
Fields
flags: TTF_SubStringFlagsThe flags for this substring
offset: c_intThe byte offset from the beginning of the text
length: c_intThe byte length starting at the offset
line_index: c_intThe index of the line that contains this substring
cluster_index: c_intThe internal cluster index, used for quickly iterating
rect: SDL_RectThe rectangle, relative to the top left of the text, containing the substring