TTF_SubStringFlags

Struct TTF_SubStringFlags 

#[repr(transparent)]
pub struct TTF_SubStringFlags(pub Uint32);
Flags for TTF_SubString

Availability

This datatype is available since SDL_ttf 3.0.0.

See also

Known values (sdl3-sys)

Associated constantGlobal constantDescription
DIRECTION_MASKTTF_SUBSTRING_DIRECTION_MASKThe mask for the flow direction for this substring
TEXT_STARTTTF_SUBSTRING_TEXT_STARTThis substring contains the beginning of the text
LINE_STARTTTF_SUBSTRING_LINE_STARTThis substring contains the beginning of line line_index
LINE_ENDTTF_SUBSTRING_LINE_ENDThis substring contains the end of line line_index
TEXT_ENDTTF_SUBSTRING_TEXT_ENDThis substring contains the end of the text

Tuple Fields

0: Uint32

Implementations

Source

impl TTF_SubStringFlags

pub const DIRECTION_MASK: Self

The mask for the flow direction for this substring

pub const TEXT_START: Self

This substring contains the beginning of the text

pub const LINE_START: Self

This substring contains the beginning of line line_index

pub const LINE_END: Self

This substring contains the end of line line_index

pub const TEXT_END: Self

This substring contains the end of the text