TTF_TextData

Struct TTF_TextData 

#[repr(C)]
pub struct TTF_TextData {
Show 16 fields pub font: *mut TTF_Font, pub color: SDL_FColor, pub needs_layout_update: bool, pub layout: *mut TTF_TextLayout, pub x: c_int, pub y: c_int, pub w: c_int, pub h: c_int, pub num_ops: c_int, pub ops: *mut TTF_DrawOperation, pub num_clusters: c_int, pub clusters: *mut TTF_SubString, pub props: SDL_PropertiesID, pub needs_engine_update: bool, pub engine: *mut TTF_TextEngine, pub engine_text: *mut c_void,
}
Internal data for TTF_Text

Availability

This struct is available since SDL_ttf 3.0.0.

Fields

font: *mut TTF_Font

The font used by this text, read-only.

color: SDL_FColor

The color of the text, read-only.

needs_layout_update: bool

True if the layout needs to be updated

layout: *mut TTF_TextLayout

Cached layout information, read-only.

x: c_int

The x offset of the upper left corner of this text, in pixels, read-only.

y: c_int

The y offset of the upper left corner of this text, in pixels, read-only.

w: c_int

The width of this text, in pixels, read-only.

h: c_int

The height of this text, in pixels, read-only.

num_ops: c_int

The number of drawing operations to render this text, read-only.

ops: *mut TTF_DrawOperation

The drawing operations used to render this text, read-only.

num_clusters: c_int

The number of substrings representing clusters of glyphs in the string, read-only

clusters: *mut TTF_SubString

Substrings representing clusters of glyphs in the string, read-only

props: SDL_PropertiesID

Custom properties associated with this text, read-only. This field is created as-needed using TTF_GetTextProperties() and the properties may be then set and read normally

needs_engine_update: bool

True if the engine text needs to be updated

engine: *mut TTF_TextEngine

The engine used to render this text, read-only.

engine_text: *mut c_void

The implementation-specific representation of this text