#[repr(C)]pub struct TTF_CopyOperation {
pub cmd: TTF_DrawCommand,
pub text_offset: c_int,
pub glyph_font: *mut TTF_Font,
pub glyph_index: Uint32,
pub src: SDL_Rect,
pub dst: SDL_Rect,
pub reserved: *mut c_void,
}Expand description
Fields
cmd: TTF_DrawCommandtext_offset: c_intThe offset in the text corresponding to this glyph. There may be multiple glyphs with the same text offset and the next text offset might be several Unicode codepoints later. In this case the glyphs and codepoints are grouped together and the group bounding box is the union of the dst rectangles for the corresponding glyphs.
glyph_font: *mut TTF_FontThe font containing the glyph to be drawn, can be passed to TTF_GetGlyphImageForIndex()
glyph_index: Uint32The glyph index of the glyph to be drawn, can be passed to TTF_GetGlyphImageForIndex()
src: SDL_RectThe area within the glyph to be drawn
dst: SDL_RectThe drawing coordinates of the glyph, in pixels. The x coordinate is relative to the left side of the text area, going right, and the y coordinate is relative to the top side of the text area, going down.
reserved: *mut c_voidTrait Implementations
Sourceimpl Clone for TTF_CopyOperation
impl Clone for TTF_CopyOperation
Sourcefn clone(&self) -> TTF_CopyOperation
fn clone(&self) -> TTF_CopyOperation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for TTF_CopyOperation