pub unsafe extern "C" fn TTF_GetTextSubStringForLine(
text: *mut TTF_Text,
line: c_int,
substring: *mut TTF_SubString,
) -> boolExpand description
Get the substring of a text object that contains the given line.
If line is less than 0, this will return a zero length substring at the
beginning of the text with the TTF_SUBSTRING_TEXT_START flag set. If line
is greater than or equal to text->num_lines this will return a zero
length substring at the end of the text with the TTF_SUBSTRING_TEXT_END
flag set.
Parameters
text: theTTF_Textto query.line: a zero-based line index, in the range [0 .. text->num_lines-1].substring: a pointer filled in with the substring containing the offset.
Return value
Returns true on success or false on failure; call SDL_GetError() for more
information.
Thread safety
This function should be called on the thread that created the text.
Availability
This function is available since SDL_ttf 3.0.0.