pub unsafe extern "C" fn TTF_SetTextScript(
text: *mut TTF_Text,
script: Uint32,
) -> boolExpand description
Set the script to be used for text shaping a text object.
This returns false if SDL_ttf isn’t built with HarfBuzz support.
Parameters
text: the text to modify.script: an ISO 15924 code .
Return value
Returns true on success or false on failure; call SDL_GetError() for more
information.
Thread safety
This function should be called on the thread that created the text.
Availability
This function is available since SDL_ttf 3.0.0.