#[repr(transparent)]pub struct TTF_SubStringFlags(pub Uint32);Expand description
Flags for TTF_SubString
Availability
This datatype is available since SDL_ttf 3.0.0.
See also
Known values (sdl3-sys)
| Associated constant | Global constant | Description |
|---|---|---|
DIRECTION_MASK | TTF_SUBSTRING_DIRECTION_MASK | The mask for the flow direction for this substring |
TEXT_START | TTF_SUBSTRING_TEXT_START | This substring contains the beginning of the text |
LINE_START | TTF_SUBSTRING_LINE_START | This substring contains the beginning of line line_index |
LINE_END | TTF_SUBSTRING_LINE_END | This substring contains the end of line line_index |
TEXT_END | TTF_SUBSTRING_TEXT_END | This substring contains the end of the text |
Tuple Fields
0: Uint32Implementations
Sourceimpl TTF_SubStringFlags
impl TTF_SubStringFlags
Sourcepub const DIRECTION_MASK: Self
pub const DIRECTION_MASK: Self
The mask for the flow direction for this substring
Sourcepub const TEXT_START: Self
pub const TEXT_START: Self
This substring contains the beginning of the text
Sourcepub const LINE_START: Self
pub const LINE_START: Self
This substring contains the beginning of line line_index