#[repr(C)]pub struct TTF_TextData {Show 16 fields
pub font: *mut TTF_Font,
pub color: SDL_FColor,
pub needs_layout_update: bool,
pub layout: *mut TTF_TextLayout,
pub x: c_int,
pub y: c_int,
pub w: c_int,
pub h: c_int,
pub num_ops: c_int,
pub ops: *mut TTF_DrawOperation,
pub num_clusters: c_int,
pub clusters: *mut TTF_SubString,
pub props: SDL_PropertiesID,
pub needs_engine_update: bool,
pub engine: *mut TTF_TextEngine,
pub engine_text: *mut c_void,
}Expand description
Fields
font: *mut TTF_FontThe font used by this text, read-only.
color: SDL_FColorThe color of the text, read-only.
needs_layout_update: boolTrue if the layout needs to be updated
layout: *mut TTF_TextLayoutCached layout information, read-only.
x: c_intThe x offset of the upper left corner of this text, in pixels, read-only.
y: c_intThe y offset of the upper left corner of this text, in pixels, read-only.
w: c_intThe width of this text, in pixels, read-only.
h: c_intThe height of this text, in pixels, read-only.
num_ops: c_intThe number of drawing operations to render this text, read-only.
ops: *mut TTF_DrawOperationThe drawing operations used to render this text, read-only.
num_clusters: c_intThe number of substrings representing clusters of glyphs in the string, read-only
clusters: *mut TTF_SubStringSubstrings representing clusters of glyphs in the string, read-only
props: SDL_PropertiesIDCustom properties associated with this text, read-only. This field is created as-needed using TTF_GetTextProperties() and the properties may be then set and read normally
needs_engine_update: boolTrue if the engine text needs to be updated
engine: *mut TTF_TextEngineThe engine used to render this text, read-only.
engine_text: *mut c_voidThe implementation-specific representation of this text